function m_4_04_computeDensityStats(varargin)
%COMPUTEDENSITYSTATS Compute average density maps, save as images
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-04-20,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2010 INRA - Cepia Software Platform.


repImages = fullfile('images', 'mhd');

valid = Table.read(fullfile('..', 'macro', 'valid_slice.txt'));

slices = valid.rowNames(valid);

% create data buffer with valid slices
res = zeros([321 321 sum(valid.data)]);
for i = 1:length(slices)
    name = slices{i};
    fileName = fullfile(repImages, [name 'Dens321.mhd']);
    img = flipud(metaImageRead(fileName));
    res(:,:,i) = img;
end

% create arrays for stats results
resMean     = ones(321, 321) * NaN;
resCount    = ones(321, 321) * NaN;
resStd      = ones(321, 321) * NaN;
resMin      = ones(321, 321) * NaN;
resMax      = ones(321, 321) * NaN;
resMed      = ones(321, 321) * NaN;

for i = 1:321
    for j = 1:321
        values = res(i, j, :);
        values = values(isfinite(values));
        
        if isempty(values)
            continue;
        end
        
        resCount(i,j)   = length(values);
        resMean(i,j)    = mean(values);
        resStd(i,j)     = std(values);
        resMin(i,j)     = min(values);
        resMax(i,j)     = max(values);
        resMed(i,j)     = median(values);
    end
end

% on ne garde que les points pour lesquels on a au moins 5 valeurs
countMask = resCount >= 5;
resMean(~countMask) = NaN;
resMed(~countMask) = NaN;
resMin(~countMask) = NaN;
resMax(~countMask) = NaN;
resStd(~countMask) = NaN;

% convertit en images couleur
resMeanRGB  = double2rgb(resMean, jet(255), [0 1.3], [1 1 1]);
resMedRGB   = double2rgb(resMed, jet(255), [0 1.3], [1 1 1]);
resMinRGB   = double2rgb(resMin, jet(255), [0 1.3], [1 1 1]);
resMaxRGB   = double2rgb(resMax, jet(255), [0 1.3], [1 1 1]);
resStdRGB   = double2rgb(resStd, jet(255), [0 .3], [1 1 1]);

ensureDirExists('images');
imwrite(resMeanRGB, 'images/resMean.png');
imwrite(resMedRGB, 'images/resMed.png');
imwrite(resMinRGB, 'images/resMin.png');
imwrite(resMaxRGB, 'images/resMax.png');
imwrite(resStdRGB, 'images/resStd.png');


%% Moyennes par genotype

% allocation memoire
resMeanGeno     = zeros(321, 321, 2);
resCountGeno    = zeros(321, 321, 2);
resStdGeno      = zeros(321, 321, 2);
resMinGeno      = zeros(321, 321, 2);
resMaxGeno      = zeros(321, 321, 2);
resMedianGeno   = zeros(321, 321, 2);

% geno = {1 pour sauvage, 2 pour mutant}
genotypes = strncmp(slices, 'm', 1)+1;

for i = 1:321
    for j = 1:321
        for geno = 1:2
            values = res(i, j, genotypes==geno);
            values = values(isfinite(values));

            if isempty(values)
                continue;
            end

            resCountGeno(i,j, geno)   = length(values);
            resMeanGeno(i,j, geno)    = mean(values);
            resStdGeno(i,j, geno)     = std(values);
            resMinGeno(i,j, geno)     = min(values);
            resMaxGeno(i,j, geno)     = max(values);
            resMedianGeno(i,j, geno)  = median(values);
        end
    end
end



% cree un masque pour les zones on a au moins 5 valeurs, par genotype
countMask1 = resCountGeno(:,:,1) >= 5;
countMask2 = resCountGeno(:,:,2) >= 5;
countMasks = cat(3, countMask1, countMask2);

% on ne garde que les points pour lesquels on a au moins 5 valeurs
resMeanGeno(~countMasks) = NaN;
resMedianGeno(~countMasks) = NaN;
resMinGeno(~countMasks) = NaN;
resMaxGeno(~countMasks) = NaN;
resStdGeno(~countMasks) = NaN;

% convertit chaque genotype en image RGB
resMeanS    = double2rgb(resMeanGeno(:,:,1),    jet(255), [0 1.3], [1 1 1]);
resMedianS  = double2rgb(resMedianGeno(:,:,1),  jet(255), [0 1.3], [1 1 1]);
resMinS     = double2rgb(resMinGeno(:,:,1),     jet(255), [0 1.3], [1 1 1]);
resMaxS     = double2rgb(resMaxGeno(:,:,1),     jet(255), [0 1.3], [1 1 1]);
resStdS     = double2rgb(resStdGeno(:,:,1),     jet(255), [0 .3], [1 1 1]);

resMeanM    = double2rgb(resMeanGeno(:,:,2),    jet(255), [0 1.3], [1 1 1]);
resMedianM  = double2rgb(resMedianGeno(:,:,2),  jet(255), [0 1.3], [1 1 1]);
resMinM     = double2rgb(resMinGeno(:,:,2),     jet(255), [0 1.3], [1 1 1]);
resMaxM     = double2rgb(resMaxGeno(:,:,2),     jet(255), [0 1.3], [1 1 1]);
resStdM     = double2rgb(resStdGeno(:,:,2),     jet(255), [0 .3], [1 1 1]);


% sauvegarde les images resultat
ensureDirExists('images');

imwrite(resMeanM, 'images/resGenoMutMean.png');
imwrite(resMedianM, 'images/resGenoMutMed.png');
imwrite(resMinM, 'images/resGenoMutMin.png');
imwrite(resMaxM, 'images/resGenoMutMax.png');
imwrite(resStdM, 'images/resGenoMutStd.png');

imwrite(resMeanS, 'images/resGenoWtMean.png');
imwrite(resMedianS, 'images/resGenoWtMed.png');
imwrite(resMinS, 'images/resGenoWtMin.png');
imwrite(resMaxS, 'images/resGenoWtMax.png');
imwrite(resStdS, 'images/resGenoWtStd.png');




