function m_2_01_segmentBundles
%SEGMENTBUNDLES segment vascular bundles in a macroscopic maize stem image 
%   
%   input: macro/images/original
%   output: macro/images/segBundles
%
% ------
% Author: David Legland
% e-mail: david.legland@nantes.inra.fr
% Created: 2007-06-26,    using Matlab 7.4.0.287 (R2007a)
% Copyright 2007 INRA - BIA PV Nantes - MIAJ Jouy-en-Josas.


repImg = fullfile('images', 'original');
repBin = fullfile('images', 'segBundles');

if ~exist(repBin, 'dir')
    mkdir(repBin);
end

list = dir(fullfile(repImg, '*.tif'));

for iImg = 1:length(list)
    name = list(iImg).name(1:4);
    disp(['process ' name]);
    
    img = imread(fullfile(repImg, list(iImg).name));

    % use alternate sequential filtering, to remove small cell walls while
    % keeping image of bundles
    for i = 1:10
        se  = strel('disk', 2*i);
        img = imclose(imopen(img, se), se);
    end

    % trouve les maxima etendus.
    emax30 = imextendedmax(img, 30, 4);
    emax20 = imextendedmax(img, 20, 4);
    bin0 = emax20 | emax30;

    % use distance function to separate touching bundles
    dist = bwdist(~bin0);
    dmax = imextendedmax(dist, 4, 8);
    imp = imimposemin(imcomplement(img), dmax, 8);
    wat = watershed(imp, 8);

    % combine with original marker image
    seg = bin0 & imerode(wat > 0, ones(5, 5));

    % ouverture morpho sur les nouvelles regions
    seg = imerode(imopen(seg, strelDisk(20)), [0 1 0;1 1 1;0 1 0]);
    
    imwrite(seg, fullfile(repBin, [name 'BunBin.tif']));
end
