function m_2_02_locateBundles
% Compute position of bundles in image coordinate system
%
%   input: macro/images/segBundles
%   output: macro/tables/bundlesPx and macro/tables/bundlesMm
%
%
%   Requires Image processing toolbox
%   
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2008-03-10,    using Matlab 7.4.0.287 (R2007a)
% Copyright 2008 INRA - BIA PV Nantes - MIAJ Jouy-en-Josas.


%% Initialisations

% working directories
repImg  = fullfile('images', 'segBundles');
repTbl  = fullfile('tables');

% image resolution in microns
resol = 3.623;

% ensure output directories exist
if ~exist(fullfile(repTbl, 'bundlesPx'), 'dir')
    mkdir(fullfile(repTbl, 'bundlesPx'));
end
if ~exist(fullfile(repTbl, 'bundlesMm'), 'dir')
    mkdir(fullfile(repTbl, 'bundlesMm'));
end

% iterate over images in directory
list = dir(fullfile(repImg, '*.tif'));
for i = 1:length(list)
    
    name = list(i).name(1:4);
    
    % read image and convert to labels
    img = imread(fullfile(repImg, [name 'BunBin.tif']));

    lbl = bwlabel(img);
    centroids = imCentroid(lbl);
    
    varNames = {'xCentroid', 'yCentroid'};
    
    % name of bundles are composed of image name and bundle index
    N = max(lbl(:));
    indNames = cellstr(num2str((1:N)', [name '-b%d']));
    
    % save bundle coordinates in pixels
    tabPx = Table.create(centroids, varNames, indNames);
    write(tabPx, fullfile(repTbl, 'bundlesPx', [name 'BunPx.txt']));
    
    % save bundle coordinates in milimeters
    centroidsMm = centroids * resol / 1000;
    tabMm = Table.create(centroidsMm, varNames, indNames);
    write(tabMm, fullfile(repTbl, 'bundlesMm', [name 'BunMm.txt']));
end
