function m_2_03_segmentContours
%SEGMENTCONTOURS Transform slice images into contour polygons
%
%   input: macro/images/segMask
%   output: 
%       macro/tables/contoursPx     -> using pixel coords.
%       macro/tables/contoursMm     -> using millimeters coordinates
%       macro/tables/contoursMmC    -> after centering
%
%   Requires:
%   Image Processing Toolbox
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2009-03-23,    using Matlab 7.4.0.287 (R2007a)
% Copyright 2008 INRA - BIA PV Nantes - MIAJ Jouy-en-Josas.


%% Init

% input images directory
repImg  = fullfile('images', 'segMask');

% output directory
repTbl = fullfile('tables');
if ~exist(repTbl, 'dir')
    mkdir(repTbl);
    mkdir(fullfile(repTbl, 'contoursPx'));
    mkdir(fullfile(repTbl, 'contoursMm'));
    mkdir(fullfile(repTbl, 'contoursMmC'));
end

list = dir(fullfile(repImg, '*.tif'));
for i = 1:length(list)
    name = list(i).name(1:4);
    disp(['process ' name]);

    % read image of segmented stem
    img = imread(fullfile(repImg, [name 'Stem.tif']));
    
    % apply morphological closing of radius 30 to smooth boundary
    img = imclose(img, strel('disk', 30, 6));
    
    % extract the boundary
    B       = bwboundaries(img, 'noholes');
    
    % transform into polygon, by switching coordinates
    poly    = B{1};
    poly    = poly(:, [2 1]);
    
    % name of columns and rows
    varNames = {'x', 'y'};
    N       = size(poly, 1);
    indNames = cellstr(num2str((1:N)', '%d'));
    
    % save coordinates in pixels
    tab     = Table.create(poly, varNames, indNames);
    format  = '%-5s %4d %4d\n';
    write(tab, fullfile(repTbl, 'contoursPx', [name 'CntPx.txt']), format);
    
    % convert into millimeters and save 
    poly    = poly * 3.623 / 1000;
    tab     = Table.create(poly, varNames, indNames);
    format  = '%-5s %8.6f %8.6f\n';
    write(tab, fullfile(repTbl, 'contoursMm', [name 'CntMm.txt']), format);

    
%     % compute centroid
%     centro  = polygonCentroid(poly);
%     
%     % recentre the polygon to have centroid on the origin
%     poly = transformPoint(poly, createTranslation(-centro));
%     
%     % reverse the polygon to point upwards
%     poly = [poly(:,1) -poly(:,2)];
%     
%     % create the result data table
%     indNames = cellstr(num2str((1:N)', '%d'));
%     varNames = {'x', 'y'};
%     tab = Table.create(poly, varNames, indNames);
%     
%     % sauve le tableau de donnees ('C' pour centre)
%     write(tab, fullfile(repTbl, 'contoursMmC', [name 'CntMmC.txt']));

end