function m_2_04_recenterData(varargin)
%GROUPDATABUNDLES translate slice bundles and contour to be centered at origin
%
%   input: macro/tables/contoursMm and macro/tables/bundlesMm 
%   output: 
%       macro/tables/bundlesMmC
%       macro/tables/bundlesMmC
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2012-02-16,    using Matlab 7.9.0.529 (R2009b)

%% Working directories

contourDir = fullfile('tables', 'contoursMm');
bundlesDir = fullfile('tables', 'bundlesMm');

contourOutputDir = fullfile('tables', 'contoursMmC');
bundlesOutputDir = fullfile('tables', 'bundlesMmC');
if ~exist(contourOutputDir, 'dir')
    mkdir(contourOutputDir);
end
if ~exist(bundlesOutputDir, 'dir')
    mkdir(bundlesOutputDir);
end


%% Iterate over contour-bundles file pairs
list = dir(fullfile(contourDir, '*.txt'));
for i = 1:length(list)
    name = list(i).name(1:4);
    
    % read contour
    tab = Table.read(fullfile(contourDir, [name 'CntMm.txt']));
    contour = tab.data;
    
    % compute contour centroid
    centroid = polygonCentroid(contour);
    
    % recenter contour
    contour = bsxfun(@minus, contour, centroid);
    
    % make contour pointing upwards
    contour(:,2) = -contour(:,2);
    
    % ensure contours are oriented Counter-Clockwise (CCW)
    if polygonArea(contour) < 0
        contour = contour(end:-1:1, :);
    end
    
    % remove last point of contour if they are the same
    if sum(contour(1,:) ~= contour(end,:)) == 0
        contour = contour(1:end-1, :);
    end
    
    % save centered contours
    tab = Table(contour, {'x', 'y'});
    write(tab, fullfile(contourOutputDir, [name 'CntMmC.txt']));

    
    % read bundles coordinate
    tab = Table.read(fullfile(bundlesDir, [name 'BunMm.txt']));
    bundles = tab.data;
    
    % recenter bundles
    bundles = bsxfun(@minus, bundles, centroid);
    
    % make buindles pointing upwards
    bundles(:,2) = -bundles(:,2);
    
    % remove bundles not in contour
    in = isPointInPolygon(bundles, contour);
    if sum(~in) > 0
        disp(sprintf('remove %d points in slice %s', sum(~in), name)); %#ok<DSPS>
    end
    bundles = bundles(in, :);
    
    % save centered and filtered bundles
    tab = Table(bundles, {'x', 'y'});
    write(tab, fullfile(bundlesOutputDir, [name 'BunMmC.txt']));
    
end
