function m_2_05_plotSlices(varargin)
%Plot all slices (bundles position and slice contours) 
%
%   Results are stored in macro/plots/slices in PNG format.
%
%   Example
%   m_3_03_plotRegisterSlices
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2013-10-22,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2013 INRA - Cepia Software Platform.

bundlesDir = fullfile('tables', 'bundlesMmC');

contoursDir = fullfile('tables', 'contoursMmC');


plotsDir = fullfile('plots', 'slices');
if ~exist(plotsDir, 'dir')
    mkdir(plotsDir);
end

list = dir(fullfile(contoursDir, '*.txt'));

for i = 1:length(list)
    
    name = list(i).name(1:4);
    
    % read registered contour
    tab = Table.read(fullfile(contoursDir, [name 'CntMmC.txt']));
    contour = tab.data;
    
    % read registered contour
    tab = Table.read(fullfile(bundlesDir, [name 'BunMmC.txt']));
    bundles = tab.data;
    
    figure(1); clf;
    drawPolygon(contour);
    hold on;
    drawPoint(bundles, 'color', 'b', 'marker', '+');

    axis equal;
    axis([-10 10 -10 10]);
    title(name);
    
    print(gcf, fullfile(plotsDir, [name 'BunCntMmC.png']), '-dpng');
end