function m_2_05_simplifyContours()
% Reduces the number of points of contours (centered and converted to mm)
%
%   Use the Douglas-Peucker algorithm to simplify the contour of the
%   slices. A tolerance value equal to 100 microns is used.
%
%   inputs: macro/tables/contoursMmC
%   outputs: macro/tables/contoursMmCDp100
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2009-04-30,    using Matlab 7.7.0.471 (R2008b)
% Copyright 2009 INRA - Cepia Software Platform.


% repertoires source et destination
inputDir  = fullfile('tables', 'contoursMmC');
outputDir = fullfile('tables', 'contoursMmDp100');

if ~exist(outputDir, 'dir')
    mkdir(outputDir);
end

% iteration sur tous les fichiers du repertoire
list = dir(fullfile(inputDir, '*.txt'));
for i = 1:length(list)
    % nom du fichier courant
    name = list(i).name(1:4);
    
    % lit les donnees du contour
    tab = Table.read(fullfile(inputDir, list(i).name));
    poly = tab.data;
    
    % simplifie le contour par algo Douglas-Peucker, avec distance de
    % 100 microns
    poly = simplifyPolygon(poly, .1);
    
    % save simplified polygon
    tab = Table.create(poly, tab.colNames);
    write(tab, fullfile(outputDir, [name 'CntMmDp100.txt']));
end
