function m_3_01_rotateMacroSlices
%REGMACROSLABFIT Rotate slices such that the fit the individual slab model
%
%   inputs: 
%       ../macro/tables/contoursMmC     centered slice contour 
%       ../macro/tables/bundlesMmC      centered bundles
%       ../slabs/tables/fitGSC/stem_slab  contour model of individual slabs
%
%   output: 
%       tables/contoursRot     rotated slice contour coordinates 
%       tables/bundles/Rot     rotated bundles coordinates
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2009-06-23,    using Matlab 7.7.0.471 (R2008b)
% Copyright 2009 INRA - Cepia Software Platform.



fittedContourDir = fullfile('..', 'slabs', 'tables', 'fitGSC', 'stem_slab');

inputContourDir = fullfile('..', 'macro', 'tables', 'contoursMmC');
inputBundlesDir = fullfile('..', 'macro', 'tables', 'bundlesMmC');

outputContourDir = fullfile('tables', 'contoursRot');
outputContourDir2 = fullfile('tables', 'contoursRotDp100');
outputBundlesDir = fullfile('tables', 'bundlesRot');

if ~exist(outputContourDir, 'dir')
    mkdir(outputContourDir);
end
if ~exist(outputContourDir2, 'dir')
    mkdir(outputContourDir2);
end
if ~exist(outputBundlesDir, 'dir')
    mkdir(outputBundlesDir);
end


files = dir(fullfile(inputContourDir, '*.txt'));

for iSlice = 1:length(files)
    
    name = files(iSlice).name(1:4);
    disp(['Process: ' name]);
   
    %% Lecture contours scannes
    
    % extrait meta infos
    stemName    = name(1:3);
    slabName    = upper(name(4));
    
    % nom de fichier
    pattern     = 'stem=%s;slab=%s.txt';
    fileName    = sprintf(pattern, stemName, slabName);
    
    % read data table
    tabSlab     = Table.read(fullfile(fittedContourDir, fileName));
    polySlab    = tabSlab.data;
    
    
    %% Read macroscopic contour
    
    % read the original contour file
    tab         = Table.read(fullfile(inputContourDir, files(iSlice).name));
    poly        = tab.data;
    
    % reduce number of vertices to 1000, to reduce computation time
    polyMacro   = resamplePolygon(poly, 1000);
    
    
    %% Compute difference between polygons for various rotation angles
    
    % for some slices, it is better to keep the original contour
    keepOriginal = {'s03a', 's07g'};
    if ismember(name, keepOriginal)
        thetaMin = 0;
        disp(thetaMin);
    else
        
        % passe par une fonction d'optimisation pour trouver l'angle de rotation
        % optimal
        tic;
        thetaMin    = fminbnd(...
            @(theta) sum(distancePointPolygon(transformPoint(polyMacro, createRotation(theta)), polySlab).^2), ...
            -pi/8, pi/8);
        toc
        disp(thetaMin);
    end
    
    % cree le contour tourne de maniere optimale
    rot         = createRotation(thetaMin);
    
    % save rotated macroscopic contour
    polyRot     = transformPoint(poly, rot);
    tab         = Table(polyRot, {'x', 'y'});
    write(tab, fullfile(outputContourDir, [name 'CntRot.txt']));
    
    % also save simplified version
    polyRot2    = simplifyPolygon(polyRot, .1);
    tab         = Table(polyRot2, {'x', 'y'});
    write(tab, fullfile(outputContourDir2, [name 'CntRotDp100.txt']));
    
    
    %% Apply same rotation transform to bundles
    
    tab = Table.read(fullfile(inputBundlesDir, [name 'BunMmC.txt']));
    bunRot = transformPoint(tab.data, rot);
     
    tab = Table(bunRot, {'x', 'y'});
    write(tab, fullfile(outputBundlesDir, [name 'BunRot.txt']));
    
end

