function m_3_02_plotRotatedContours
%REGMACROSLABFIT Display the result of slice rotation, together with ref slab
%   
%   Outputs are stored in plots/contoursRot.
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2009-06-23,    using Matlab 7.7.0.471 (R2008b)
% Copyright 2009 INRA - Cepia Software Platform.



fittedContourDir = fullfile('..', 'slabs', 'tables', 'fitGSC', 'stem_slab');
inputContourDir = fullfile('..', 'macro', 'tables', 'contoursMmC');
rotatedContoursDir = fullfile('tables', 'contoursRot');

plotsDir = fullfile('plots', 'contoursRot');
if ~exist(plotsDir, 'dir')
    mkdir(plotsDir);
end


files = dir(fullfile(inputContourDir, '*.txt'));

for iSlice = 1:length(files)
    
    name = files(iSlice).name(1:4);
       
    %% Lecture contours scannes
    
    % extrait meta infos
    stemName    = name(1:3);
    slabName    = upper(name(4));
    
    % nom de fichier
    pattern     = 'stem=%s;slab=%s.txt';
    fileName    = sprintf(pattern, stemName, slabName);
    
    % read data table
    tabSlab     = Table.read(fullfile(fittedContourDir, fileName));
    polySlab    = tabSlab.data;
    
    
    %% Read original macroscopic contour
    
    % read the original contour file
    tab         = Table.read(fullfile(inputContourDir, files(iSlice).name));
    poly        = tab.data;
    
    % reduce number of vertices to 1000, to reduce computation time
    polyMacro   = resamplePolygon(poly, 1000);
    
    
    %% Read rotated macroscopic contour
     
    tab = Table.read(fullfile(rotatedContoursDir, [name 'CntRot.txt']));
    polyRot = tab.data;
    
    %% Display all contours
    
    figure(1); clf; hold on;
    drawPolygon(polySlab, 'linewidth', 2, 'color', 'k');
    drawPolygon(polyMacro);
    drawPolygon(polyRot, 'r');

    axis equal;
    axis([-10 10 -10 10]);
    title(name);
    
    print(gcf, fullfile(plotsDir, [name 'CntRot.png']), '-dpng');
    
end

