function m_1_02_computeSlabContours(varargin)
%COMPUTESLABOUTLINES Compute contour of each slab as a closed polygon
%   output = slabOutlineAll(input)
%
%   Example
%   slabOutlineAll
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2009-06-18,    using Matlab 7.7.0.471 (R2008b)
% Copyright 2009 INRA - Cepia Software Platform.

% input directory
repImg = fullfile('images', 'segBySlab');

% create output directories if necessary
repPx = fullfile('tables', 'contoursPx');
if ~exist(repPx, 'dir')
    mkdir(repPx);
end
repMm = fullfile('tables', 'contoursMm');
if ~exist(repMm, 'dir')
    mkdir(repMm);
end

% image resolution (720 dpi), in mm/pixel
resol = 25.4/720;

files = dir(fullfile(repImg, '*.tif'));

for i = 1:length(files)
    % name of the current slab image
    fileName = files(i).name;
    name = fileName(1:end-4);
    
    % read image
    img = imread(fullfile(repImg, [name '.tif']));
    
    % morphological filtering to remove noise
    img = imopen(img, ones(3, 3));
    
    % compute image boundary
    bnd = img ~= imerode(img, [0 1 0;1 1 1;0 1 0]);
    
    % extract polygon
    poly = imChainPixels(bnd);
    
    % save the polygon in pixel coords
    tab = Table.create(poly, {'x', 'y'});
    write(tab, fullfile(repPx, [name 'CntPx.txt']), '%d %d');
    
    
    % conversion into user unit (millimeters)
    polyMm = poly * resol;
  
    % recentre the polygon
    center  = polygonCentroid(polyMm);
    polyMm = bsxfun(@minus, polyMm, center);

    % also point upwards instead of downwards
    polyMm(:,2) = -polyMm(:,2);

    % save centered polygon in user units
    tab = Table.create(polyMm, {'x', 'y'});
    write(tab, fullfile(repMm, [name 'CntMm.txt']));
end
