function m_1_03_rotateContours(varargin)
%ROTATECONTOURS  Rotate all slab contours such that they point upwards
%
%   Inputs are in slabs/tables/contoursMm
%   Outputs are in slabs/tables/contoursMmCR
%   (CR stands for centered and rotated)
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2009-06-18,    using Matlab 7.7.0.471 (R2008b)
% Copyright 2009 INRA - Cepia Software Platform.

% repertoire des images de bloc
repTbl = fullfile('tables', 'contoursMm');

% ensures the output directory exist
repDst = fullfile('tables', 'contoursMmCR');
if ~exist(repDst, 'dir')
    mkdir(repDst);
end

files = dir(fullfile(repTbl, '*.txt'));

for i = 1:length(files)
    % extract the name of the contour
    fileName = files(i).name;
    name = fileName(1:5);
    
    % display current slab contour
    disp(['process : ' name]);
    
    % read the contour polygon
    tab     = Table.read(fullfile(repTbl, [name 'CntMm.txt']));
    poly    = tab.data;
    
    % compute symmetric wrt the vertical axis
    polySym = [-poly(:,1) poly(:,2)];
    
    % determines the rotation angle that best matches the polygon with the
    % rotated polygon
    tic;
    thetaMin = fminbnd(...
        @(theta) sum(distancePointPolygon(transformPoint(polySym, createRotation(theta)), poly).^2), ...
        -pi/4, pi/4);
    toc
    
    % divide angle by 2 for aligning polygon with vertical axis
    rot     = createRotation(-thetaMin/2);
    polyRot = transformPoint(poly, rot);
    
    
    % in the case of a 'verso' image, use the symetric wrt the vertical
    % axis, such that all contours are oriented in the same direction
    if name(end) == 'v'
        polyRot(:,1) = -polyRot(:,1);
    end
    
    % save the rotated polygon
    tab = Table.create(polyRot, {'x', 'y'});
    write(tab, fullfile(repDst, [name 'CntMmCR.txt']));
    
end
