function m_1_04_concatSlabContoursN200(varargin)
%CONCATOUTLINEN200  Reduce all slab contour to 200 vertices
%
%   Inputs are in slabs/contoursMmCR, 
%   Ouptuts are in slabs/contoursMmCRN200, 
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2009-06-18,    using Matlab 7.7.0.471 (R2008b)
% Copyright 2009 INRA - Cepia Software Platform.

% repertoire des images de bloc
repSrc = fullfile('tables', 'contoursMmCR');

% repertoire des images de bloc
repDst = fullfile('tables', 'contoursMmCRN200');
if ~exist(repDst, 'dir')
    mkdir(repDst);
end

% list of files to process
files = dir(fullfile(repSrc, '*.txt'));
Nf = length(files);

% nombre de points du contour simplifie
N = 200;

% allocation memoire
dat = zeros(Nf, 2*N);
rowNames = cell(Nf, 1);

for i = 1:length(files)
    % extrait le nom du bloc
    fileName = files(i).name;
    name = fileName(1:5);

    %% read and pre-process input polygon
    
    % lecture du polygone
    tab  = Table.read(fullfile(repSrc, [name 'CntMmCR.txt']));
    poly = tab.data;
    
    % nombre de points du polygone
    np      = size(poly, 1);
    
    % indices des points au dessus de l'axe des abscisses
    indSup  = find(poly(:,2) > 0);
    
    % parmis les points au dessus, trouve celui le plus proche de l'axe (Oy)
    [tmp ind] = min(abs(poly(indSup,1))); %#ok<ASGLU>
    
    % recupere l'indice du point par rapport a la numerotation du polygone
    ind     = indSup(ind);
    
    % decale les sommets du polygone pour commencer au point le plus haut
    poly    = circshift(poly, [1-ind 0]);
    
    % verifie que le polygone tourne dans le bon sens (anti-horaire)
    if polygonArea(poly) < 0
        poly = poly(end:-1:1, :);
    end
    
    % ferme le polygone (pour calcul des centroides et des longueurs)
    poly    = poly([1:end 1], :);
    
    
    %% cut polygon into same number of pieces
    
    % indices des extremites de courbes
    inds    = round(linspace(1, np+1, N+1));
    
    % alloue la memoire pour le nouveau polygone
    poly2   = zeros(N, 2);
    
    % calcule le centroide de chaque morceau de courbe
    for j = 1:N
        curve   = poly(inds(j):inds(j+1), :);
        centro  = polylineCentroid(curve);
        poly2(j,:) = centro;
    end
    

    % save current simplified polygon
    vars = {'x', 'y'};
    tab = Table.create(poly2, vars);
    write(tab, fullfile(repDst, [name 'CntCRN200.txt']), '%d %6.3f %6.3f\n');



    %%
    
    % remplit le tableau de donnees
    dat(i, 1:N)        = poly2(:,1);
    dat(i, N+1:2*N)    = poly2(:,2);    
    
    % garde le nom simplifie
    rowNames{i} = name;
    
end

% format pour sauver les nombres 
format = ['%s' repmat(' %6.3f', 1, 2*N) '\n'];

% cree le tableau de donnees avec infos
vars = [cellstr(num2str((1:N)', 'x%d'))' cellstr(num2str((1:N)', 'y%d'))'];
tab = Table.create(dat, vars, rowNames);
write(tab, fullfile('tables', 'cntCRN200XY_slab.txt'), format);

% % selectionne les donnees 'propres'
% tabFact = tableRead('../../extract/tables/fact_slab.sel.txt');
% tab     = tableSelectRows(tab, tabFact.i);
% tableWrite(tab, fullfile(repTbl, 'cntCRN200XY_slab.sel.txt'), format);
% 
% % En prime, calcul decalage de chaque point par rapport a valeur moyenne
% moy = mean(tab.d, 1);
% tab.d = tab.d - repmat(moy, length(tab.i), 1);
% tab.v = [...
%     cellstr(num2str((1:N)', 'vx%d'))' cellstr(num2str((1:N)', 'vy%d'))'];
% format = ['%s' repmat(' %8.5f', 1, 2*N) '\n'];
% tableWrite(tab, fullfile(repTbl, 'cntCRN200VxySel_slab.txt'), format);
