function anovaPcaContours(varargin)
%ANOVACP Performs Anova on the 5 first principal components of a PCA
%
%   output = anovaCP(input)
%
%   Example
%   anovaCP
%
%   See also
%
%
% ------
% Author: David Legland
% e-mail: david.legland@grignon.inra.fr
% Created: 2013-05-28,    using Matlab 7.9.0.529 (R2009b)
% Copyright 2013 INRA - Cepia Software Platform.

% read table of selected contours
tab = Table.read(fullfile('tables', 'cntCRN200XY_slab.sel.txt'));

% compute Principal component analysis, and keep ten components
resPca = Pca(tab, 'scale', false, 'display', 'off');
co = resPca.scores.data(:, 1:10);

% extract factors
fact = Table.read(fullfile('tables', 'fact2_slab.sel.txt'));
geno = fact('geno');
stem = fact('stem');
cut  = fact('cut');

% create the model for anova
groups = [geno stem cut];
model = [1 0 0; 0 0 1;1 0 1;0 1 0];
nested = [0 0 0;1 0 0;0 0 0];

% store the results of anova in a new table
res = zeros(4, 5);
for i = 1:5
    res(:,i) = anova(co(:,i), groups, ...
        'model', model, ...
        'nested', nested, ...
        'random', 2, ...
        'display', 'off');
end

% save anova results
colNames = {'cp1', 'cp2', 'cp3', 'cp4', 'cp5'};
rowNames = {'geno', 'cut', 'geno*cut', 'stem'};
tabRes = Table(res, colNames, rowNames);

write(tabRes, fullfile('tables', 'cntCRN200XY_slab.sel.co.anova.txt'));
